==> thunderbird_16.0.1%2Bbuild1-0ubuntu0.10.04.1.debian.tar.gz: debian/eds/content/newContactOverlay.js <==
/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
/* ***** BEGIN LICENSE BLOCK *****
 *	 Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is edsintegration.
 *
 * The Initial Developer of the Original Code is
 * Mozilla Corp.
 * Portions created by the Initial Developer are Copyright (C) 2011
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * Mike Conley <mconley@mozilla.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */

Components.utils.import("resource:///modules/mailServices.js");
Components.utils.import("resource://edsintegration/nsAbEDSCommon.jsm");

var EDSNewContactEditor = {
  init: function EDSNCE_init(aDocument) {
    LOG("Init'ing EDSNewContactEditor");
    var menu = aDocument.getElementById("abPopup");

    menu.setAttribute("oncommand", "EDSNewContactEditor.abChanged(this);");
    EDSNewContactEditor.abChanged(menu);
    LOG("Done init'ing EDSNewContactEditor");
  },

  abChanged: function EDSNCE_abChanged(aMenuList) {
    LOG("New contact editor address book changed");
    let uri = aMenuList.value;
    let ab = MailServices.ab.getDirectory(uri);
    try {
      // Try to query as an nsIAbEDSDirectory
      ab.QueryInterface(Components.interfaces.nsIAbEDSDirectory);
    } catch(e) {
      // Set interface for a standard nsIAbCard
      EDSContactEditor.goInert(document);
      return;
    }
    EDSContactEditor.goActive(document, ab);

  }

}


window.addEventListener("load", function() {
  EDSNewContactEditor.init(document);
});

==> thunderbird_31.0%2Bbuild1-0ubuntu0.14.04.1.debian.tar.gz: debian/eds/content/newContactOverlay.js <==
/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
/* ***** BEGIN LICENSE BLOCK *****
 *	 Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is edsintegration.
 *
 * The Initial Developer of the Original Code is
 * Mozilla Corp.
 * Portions created by the Initial Developer are Copyright (C) 2011
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * Mike Conley <mconley@mozilla.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */

Components.utils.import("resource:///modules/mailServices.js");
Components.utils.import("resource://edsintegration/modules/nsAbEDSCommon.jsm");

var EDSNewContactEditor = {
  init: function EDSNCE_init(aDocument) {
    var menu = aDocument.getElementById("abPopup");

    menu.setAttribute("oncommand", "EDSNewContactEditor.abChanged(this);");
    EDSNewContactEditor.abChanged(menu);
  },

  abChanged: function EDSNCE_abChanged(aMenuList) {
    let uri = aMenuList.value;
    let ab = MailServices.ab.getDirectory(uri);
    try {
      // Try to query as an nsIAbEDSDirectory
      ab.QueryInterface(Components.interfaces.nsIAbEDSDirectory);
    } catch(e) {
      // Set interface for a standard nsIAbCard
      EDSContactEditor.goInert(document);
      return;
    }
    EDSContactEditor.goActive(document, ab);

  }
};

window.addEventListener("load", function() {
  EDSNewContactEditor.init(document);
});
